@@ -231,11 +231,21 @@ class ArduStack:
     def _close(self):
         if self.vehicle is not None:
             self.vehicle.close()
-        self.container.stop()
+
+        if not self.config.use_dronekit_sitl:
+            self.container.stop()
+        else:
+            self.sitl.stop()
 
     def execute(self, mission: Mission):
         retry_count = 0
-        self.container = self._start_container(mission)
+
+        if not self.config.use_dronekit_sitl:
+            self.container = self._start_container(mission)
+        else:
+            import dronekit_sitl
+            self.sitl = dronekit_sitl.start_default()
+            self.config.connection_string = self.sitl.connection_string()
 
         print("Connecting to {}".format(self.config.connection_string))
 
@@ -247,7 +257,13 @@ class ArduStack:
                 print("Retrying {}".format(retry_count))
                 self._close()
                 time.sleep(5)
-                self.container = self._start_container(mission)
+                
+                if not self.config.use_dronekit_sitl:
+                    self.container = self._start_container(mission)
+                else:
+                    self.sitl = dronekit_sitl.start_default()
+                    self.config.connection_string = self.sitl.connection_string()
+
                 try:
                     self.vehicle = connect(self.config.connection_string, wait_ready=True, heartbeat_timeout=60)
                     print(self.vehicle)
